@@ -1,10 +1,16 @@
 #!/bin/sh -
 
+# run as user 
+
+
 # installation based on python
 # but excluding conda environments. 
-/usr/bin/python3 -m pip install --upgrade pip
-pip3 install -U diff-pdf-visually
-pip3 install -U unoserver
+#/usr/bin/python3 -m pip install --upgrade pip
+
+pipx install diff-pdf-visually
+pipx install unoserver
+#pip3 install -U python3-oct2py # library 
+pipx upgrade-all
 
 #see https://pypi.org/project/unoserver/: 
 #To find all Python installations that have the relevant LibreOffice libraries installed, you can run a script called find_uno.py:
