@@ -40,7 +40,10 @@ chmod a+x /usr/bin/CODE
 # chmod a+x /usr/bin/onionshare
 
 # my personal printer driver... well not very generic (TBD: change that)
-rpm -i hll2350dwpdrv-4.0.0-1.i386.rpm
+#rpm -i hll2350dwpdrv-4.0.0-1.i386.rpm
+
+# to locate e.g. my second monitor 
+zypper in -y plocate libxcvt
 
 # to replace dropbox 
 zypper in -y tor torbrowser-launcher # python3-onionshare 
@@ -51,9 +54,9 @@ zypper in -y MozillaThunderbird MozillaThunderbird-translations-common
 # Also ensure that there is a link to thunderbird on the desktop
 
 # addrepo.sh adds special repo for that 
-zypper in -y google-chrome-stable mathjax
+zypper in -y google-chrome-stable mathjax dhcp-client
 
-zypper in -y gstreamer-plugin-openh264 mozilla-openh264
+zypper in -y mozilla-openh264 # gstreamer-plugin-openh264 
 
 # `okular` and `okular-lang` are installed in basic version but needed are also
 # calligra to allow odp,... and spectre for forms 
@@ -109,7 +112,6 @@ zypper in -y \
   texlive-hanging     texlive-stackengine texlive-tocloft texlive-etoc `# for doxygen` \
   texlive-draftwatermark texlive-draftwatermark-doc `# for watermarks like confidential or DRAFT` \
   texlive-jupynotex-doc `# for jupyter notebook` \
-
   texlive-latex2man   texlive-latex2nemeth `# converter` \
   texlive-pdfprivacy  texlive-pdfprivacy-doc `# for pdf` \
   texlive-hyperref    texlive-hyperxmp texlive-hyperxmp-doc `# hyperref and related` \
@@ -126,6 +128,10 @@ zypper in -y \
   texlive-adrconv      texlive-adrconv-doc   `# address database as bib file` \
   texlive-pdfpagediff texlive-pdfpagediff-doc `# for pdf` \
   texlive-showlabels texlive-showlabels-doc `# to make labels visible` \
+  texlive-changes texlive-changes-doc `# to make track changes` \
+  texlive-pdfx texlive-pdfx-doc `# to make pdf conformant to certain standards and add meta data` \
+  texlive-silence texlive-silence-doc `# to be able to silence warnings and even errors` \
+  texlive-collection-fontsrecommended `# load most important fonts` \
   texlive-stix `# additional math like widetilde ` \
   texlive-mathabx `# additional math fonts ` \
   texlive-pythontex texlive-pythontex-bin `# pythontex and depythontex (unfortunately outdated; see below) ` \
@@ -143,24 +149,79 @@ zypper in -y \
 
 zypper in -y latex2rtf `# converter`
 
-# patch package commuative-diagrams
-# TBD: wget -nc avoids downloading if it exists already
-wget -nc -O ./commutative-diagrams.tds.zip https://mirrors.ctan.org/install/graphics/pgf/contrib/commutative-diagrams.tds.zip
-cp ./commutative-diagrams.tds.zip /usr/share/texmf/
-pushd /usr/share/texmf/
-unzip -o commutative-diagrams.tds.zip
-rm commutative-diagrams.tds.zip
+message='Installed by instZypper@QMngMnt'
+
+# patch package commutative-diagrams
+# TBD: wget: 
+# -N  downloads only if the file on the server is newer or if the server does not provide a timestamp.  
+#     In fact, it is to ensure that the newest variant of that file is available locally. 
+#     This option shall be used if the file name does not include a version 
+#     or more general, if there may be a newer variant of that file with the same name 
+#     (e.g. because of a bugfix not reflected in the name of the file). 
+# -nc avoids downloading if it exists already. 
+#     This shall be used if the file name is with version or more general, 
+#     if there may be no newer variant on the server with the same name. 
+
+
+# ltex-plus replaced ltex because the latter seems no longer supported 
+versionLTexPlus=18.5.1
+# TBD: this must ge generalized 
+platformLTex=x64
+mkdir -p /usr/share/ltex 
+pushd /usr/share/ltex
+#https://github.com/ltex-plus/ltex-ls-plus/releases/latest 
+# exists but did not find a way to 
+wget -nc https://github.com/ltex-plus/ltex-ls-plus/releases/download/$versionLTexPlus/ltex-ls-plus-$versionLTexPlus-linux-$platformLTex.tar.gz
+gunzip --force --keep ltex-ls-plus-*.tar.gz # keep to avoid further download 
+tar --no-overwrite-dir --no-same-owner --no-same-permissions -xf ltex-ls-plus-*.tar
+cd /usr/bin
+ln -s ltex-cli-plus /usr/local/bin/ltex-cli
+ln -s ltex-ls-plus  /usr/local/bin/ltex-ls
+ln -fs ../share/ltex/ltex-ls-plus-$versionLTexPlus/bin/ltex-ls-plus  ltex-ls
+ln -fs ../share/ltex/ltex-ls-plus-$versionLTexPlus/bin/ltex-cli-plus ltex-cli
 popd
 
+pushd /usr/share/texmf/
+wget -N https://mirrors.ctan.org/install/graphics/pgf/contrib/commutative-diagrams.tds.zip
+unzip -o commutative-diagrams.tds.zip
+#rm commutative-diagrams.tds.zip signifies the patch
+echo 'commutative-diagrams.tds.zip nstalled by instZypper@QMngMnt' > commutative-diagrams.tds.r
+popd
+
+pushd /usr/share/
+wget -N https://dl.genymotion.com/releases/genymotion-3.9.0/genymotion-3.9.0-linux_x64.run
+chgmod a+x ./genymotion-3.9.0-linux_x64.run
+./genymotion-3.9.0-linux_x64.run
+#rm commutative-diagrams.tds.zip signifies the patch
+popd
+
+
 # Bugfix in fork, pull requested but so far no merge 
-wget -O /usr/share/texmf/scripts/pythontex/pythontex3.py   https://www.simuline.eu/Pythontex/pythontex3.py
-wget -O /usr/share/texmf/scripts/pythontex/depythontex3.py https://www.simuline.eu/Pythontex/depythontex3.py
+pushd /usr/share/texmf/scripts/pythontex/
+wget -N https://www.simuline.eu/Pythontex/pythontex3.py
+wget -N https://www.simuline.eu/Pythontex/depythontex3.py
+popd
 
 
 # TBD: It is not ok just to patch into an existing and clean texlive installation. 
 # To improve this, one shall install texlive in the standardized way, not via suse. 
-mkdir -p /usr/share/texmf/bibtex/bst/abstract/
-wget -nc -O /usr/share/texmf/bibtex/bst/abstract/abstract.bst http://tug.ctan.org/tex-archive/biblio/bibtex/utils/bibtools/abstract.bst
+# mkdir -p /usr/share/texmf/bibtex/bst/abstract/
+# pushd /usr/share/texmf/bibtex/bst/abstract/
+# wget -N http://tug.ctan.org/tex-archive/biblio/bibtex/utils/bibtools/abstract.bst
+# popd
+# TBD: It is not ok just to patch into an existing and clean texlive installation. 
+# To improve this, one shall install texlive in the standardized way, not via suse. 
+#mkdir -p /usr/share/texmf/bibtex/bst/abstract/
+#wget -nc -O /usr/share/texmf/bibtex/bst/abstract/abstract.bst http://tug.ctan.org/tex-archive/biblio/bibtex/utils/bibtools/abstract.bst
+
+
+
+mkdir -p /usr/share/texmf/tex/latex/tikzUml
+pushd /usr/share/texmf/tex/latex/tikzUml
+wget -N https://perso.ensta-paris.fr/~kielbasi/tikzuml/var/files/src/tikzuml-v1.0-2016-03-29.tbz
+tar xvf tikzuml*.tbz
+#rm tikzuml*.tbz signifies the patch 
+popd
 
 # # TBD: It is not ok just to patch into an existing and clean texlive installation. 
 # # To improve this, one shall install texlive in the standardized way, not via suse. 
@@ -196,33 +257,18 @@ jabrefVersion=6.0-1
 # old url
 # wget -nc -O ./jabref-$jabrefVersion.rpm https://www.fosshub.com/JabRef.html?dwl=jabref-$jabrefVersion.rpm
 # new url 
-wget -nc -O ./jabref-$jabrefVersion.rpm https://builds.jabref.org/main/jabref-$jabrefVersion.x86_64.rpm
-rpm -i ./jabref-$jabrefVersion.rpm
-pushd /usr/local/bin/
-ln -sf /opt/jabref/bin/JabRef JabRef
-popd
 
-# TBD: It is not ok just to patch into an existing and clean texlive installation. 
-# To improve this, one shall install texlive in the standardized way, not via suse. 
-mkdir -p /usr/share/texmf/bibtex/bst/abstract/
-wget -nc -O /usr/share/texmf/bibtex/bst/abstract/abstract.bst http://tug.ctan.org/tex-archive/biblio/bibtex/utils/bibtools/abstract.bst
+if rpm -q jabref; then
+  # nothing to do because rpm -1 returned 0 signifying that jabref is installed. 
+  echo 'jabref installed'
+else
+  pushd /usr/local/bin/
+  wget -N https://builds.jabref.org/main/jabref-$jabrefVersion.x86_64.rpm
+  rpm -i ./jabref-$jabrefVersion.x86_64.rpm
+  popd
+fi
+
 
-# # TBD: It is not ok just to patch into an existing and clean texlive installation. 
-# # To improve this, one shall install texlive in the standardized way, not via suse. 
-# tikzVersion=tikzuml-v1.0-2016-03-29
-# #tikzuml-v1.0-2016-03-29
-# wget -nc -O $tikzVersion.tbz https://perso.ensta-paris.fr/~kielbasi/tikzuml/var/files/src/$tikzVersion.tbz
-# chmod a+w $tikzVersion.tbz
-# if ! [[ -e $tikzVersion ]]; then
-#   tar -xvf $tikzVersion.tbz
-#   chmod -R a+w $tikzVersion
-#   pushd $tikzVersion
-#   mkdir -p /usr/share/texmf/tex/latex/tikz-uml/
-#   cp tikz-uml.sty /usr/share/texmf/tex/latex/tikz-uml/
-#   mkdir -p /usr/share/texmf/doc/latex/tikz-uml
-#   cp -r doc/* /usr/share/texmf/doc/latex/tikz-uml
-#   popd
-# fi
 
 
 # TBD: this shall be done inside the project. 
@@ -235,7 +281,7 @@ cp ./tex4ht/longtable.4ht /usr/share/texmf/tex/generic/tex4ht/longtable.4ht
 texconfig rehash # part of texlive 
 
 
-zypper in -y jabref # this did not work: older version, problem with javafx
+#zypper in -y jabref # this did not work: older version, problem with javafx
 # jabrefVersion=5.9-1.x86_64
 # wget -nc -O ./jabref-$jabrefVersion.rpm https://www.fosshub.com/JabRef.html?dwl=jabref-$jabrefVersion.rpm
 # rpm -i ./jabref-$jabrefVersion.rpm
@@ -390,7 +436,8 @@ zypper in -y perl-Capture-Tiny perl-DateTime-Format-ISO8601
 # Solution: run only if  /run/snapd.socket exists. 
 # else display a warning: restart computer and run this script again. 
 snap install whatsdesk 
-snap install whatsapp-for-linux #teams-for-linux
+#snap install whatsapp-for-linux #teams-for-linux
+#snap install whatsapp-electron #teams-for-linux
 snap install spark --edge
 snap install onionshare
 #snap install jabref
